# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tools_item_last_updated_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem,
)

TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem]],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_json_schema_item import (
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
)

AgentsSearchResponseAgentsItemToolsItemJsonSchema = typing.Union[
    typing.Optional[typing.Any],
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem]],
]
